@@ -1,11 +1,11 @@
-from __future__ import absolute_import
-
 import pytest
-from qtpy import PYSIDE2
+
+from qtpy import PYSIDE2, PYSIDE6
 
 
-@pytest.mark.skipif(not PYSIDE2, reason="Only available by default in PySide2")
+@pytest.mark.skipif(not (PYSIDE2 or PYSIDE6), reason="Only available by default in PySide")
 def test_qtcharts():
     """Test the qtpy.QtCharts namespace"""
     from qtpy import QtCharts
+    assert QtCharts.QChart is not None
     assert QtCharts.QtCharts.QChart is not None
